/*
 * YouGrabber
 *
 * A lightweight, command line YouTube.com video downloader, made from scratch
 * in ANSI C.
 *
 * Copyright (C) 2006-2007 Quetzy Garcia, <quetzyg@users.sourceforge.net>
 * For news and updates, see <http://yougrabber.sourceforge.net/>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DOWNLOAD_H
  #define DOWNLOAD_H 1
#endif

typedef struct __yg_download YGD;

typedef enum
{
  YG_DOWNLOAD_ERROR_CANCELED,
  YG_DOWNLOAD_ERROR_FILE_LIMIT,
  YG_DOWNLOAD_ERROR_CURL,
  YG_DOWNLOAD_ERROR_VIDEO_UNAVAILABLE,
  YG_DOWNLOAD_OK_WAITING,
  YG_DOWNLOAD_OK_DOWNLOADING,
  YG_DOWNLOAD_OK_FINISHED
} YGStatusDownload;

/* create a new download and return pointer */
extern YGD *yg_download_new(YGC *, char *);

/* free download resources (GFunc() type function) */
extern void yg_download_free(gpointer, gpointer);

/* get the download status */
extern int yg_download_status(YGD *);

/* get the download curl error string */
extern char *yg_download_curl_error(YGD *);

/* get the download speed */
extern double yg_download_speed(YGD *);

/* get the download elapsed time */
extern double yg_download_time(YGD *);

/* get the download file name */
extern char *yg_download_file_name(YGD *);

/* get the download current file size */
extern double yg_download_file_size_now(YGD *);

/* get the download total file size */
extern double yg_download_file_size_total(YGD *);

/* get the download video title */
extern const char *yg_download_video_title(YGD *);

/* get the download video URL */
extern char *yg_download_video_url(YGD *);
