/*
 * YouGrabber
 *
 * A lightweight, command line YouTube.com video downloader, made from scratch
 * in ANSI C.
 *
 * Copyright (C) 2006-2008 Quetzy Garcia, <quetzyg@users.sourceforge.net>
 * For news and updates, see <http://yougrabber.sourceforge.net/>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "include/common.h"

int main(int argc, char **argv)
{
  GList *d_list = NULL;
  YGC *c_ptr = NULL;
  YGI *i_ptr = NULL;
  pthread_t login;
  int i;

  setlocale (LC_ALL, "");

  if (argc < 2)
  {
    yg_print("Usage: yg [URL]...");

    return EXIT_SUCCESS;
  }

  if ((c_ptr = yg_config_new()) == NULL)
  {
    yg_print("You don't have read/write privileges in both current " \
      "and download directory,\nor there is insufficient memory " \
      "to store the configuration settings");

    return EXIT_FAILURE;
  }

  for (i = 1; i < argc; ++i)
  {
    YGD *d_ptr = NULL;

    d_ptr = yg_download_new(c_ptr, argv[i]);

    if (d_ptr)
      d_list = g_list_append(d_list, d_ptr);
  }

  if ((i_ptr = yg_interface_new(c_ptr, d_list)) == NULL)
  {
    g_list_foreach(d_list, yg_download_free, NULL);
    g_list_free(d_list);

    yg_config_free(c_ptr);

    yg_print("Insufficient memory to start the user interface");

    return EXIT_FAILURE;
  }

  if (pthread_create(&login, NULL, (void *) yg_config_login_perform, c_ptr))
  {
  	yg_interface_free(i_ptr);

    yg_print("Unable to create the login thread");

    return EXIT_FAILURE;
  }

  yg_interface_main_loop(i_ptr);

  pthread_join(login, NULL);
  yg_interface_free(i_ptr);

  return EXIT_SUCCESS;
}
